@@ -185,7 +185,7 @@ class TechStack(Utils, Meta):
 
         resolvedFilter = ''
         if where != None: 
-            resolvedFilter = Utils._resolveFilter(where)
+            resolvedFilter = Utils._resolveWhereString(where)
 
         if orderBy != None:
             if asc != True:
@@ -702,7 +702,10 @@ class TechStack(Utils, Meta):
             Use True to ignore confirmation.
         """
 
-        _result =self.items(inventoryName, ['inventoryItemId', 'inventoryId'])
+        _result =self.items(inventoryName, ['_inventoryItemId', 'inventoryId'])
+        if _result.empty:
+            logger.info(f"Inventory {inventoryName} has no items.")
+            return
         _inventoryItemIds = list(_result['_inventoryItemId'])
 
         _ids = ''
