@@ -334,7 +334,7 @@ class TimeSeries():
 
         resolvedFilter = ''
         if where != None: 
-            resolvedFilter = Utils._resolveFilter(where)
+            resolvedFilter = Utils._resolveWhereString(where)
 
         # if unit != None:
         #     _unit = f'unit:"{unit}"'
